#' Get default roles for CRediT
#'

roles_get <- function() {
    c(
    "Conceptualization",
    "Methodology",
    "Software",
    "Validation",
    "Formal analysis",
    "Investigation",
    "Resources",
    "Data curation",
    "Writing - original draft",
    "Writing - review & editing",
    "Visualization",
    "Supervision",
    "Project administration",
    "Funding acquisition"
  )
}
